//******************************************************************************
//
//  PROGRAM: SPDDE.H
//
//  PURPOSE: Defines structures for DDE conversation
//
//  FUNCTIONS:
//
//
//  COMMENTS:
//
//
//  Change History:
//
//  04/02/93  Creation                                  Yasuhide Niimura
//
//         Copyright (c) 1993, Yasuhide Niimura, IBM Corporation.
//
//                         All rights reserved.
//
//******************************************************************************

#define   WC_DDE_GLOBAL      (GHND | GMEM_DDESHARE)

//***************************************************************
//
//  Put Data to Presentation Space
//
//***************************************************************

typedef struct tagWCDDE_PUTPS
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  unsigned  uPSStart;
  unsigned  uEOFflag;
  char      Data[1];
} WCDDE_PUTPS;

typedef union tagDDE_PUTPS
{
  DDEPOKE     DDEpoke;
  WCDDE_PUTPS DDEputps;
} DDE_PUTPS;

typedef DDE_PUTPS FAR *LPDDE_PUTPS;

//***************************************************************
//
//  Send Keystrokes
//
//***************************************************************

typedef struct tagWCDDE_KEYS
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  unsigned  uKeyType;
  unsigned  uRetryCount;
  uchar     Data[1];
} WCDDE_KEYS;

typedef union tagDDE_KEYS
{
  DDEPOKE     DDEpoke;
  WCDDE_KEYS  DDEkeys;
} DDE_KEYS;

typedef DDE_KEYS FAR *LPDDE_KEYS;

//***************************************************************
//
//  Set Cursor
//
//***************************************************************

#define DDE_SETCURSOR_PSPOS    0x0000
#define DDE_SETCURSOR_ROWCOL   0x0001

typedef struct tagSETCSR
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  unsigned  uCursorSetType;
  unsigned  uCursorSetValue1;
  unsigned  uCursorSetValue2;
} SETCSR;

typedef SETCSR FAR *LPSETCSR;

typedef union tagDDE_CURSOR
{
  DDEPOKE    DDEpoke;
  SETCSR     DDESetCursor;
} DDE_CURSOR;

typedef DDE_CURSOR FAR *LPDDE_CURSOR;

//***************************************************************
//
//  Set Presentation Service Condition
//
//***************************************************************

#define DDE_UNEFFECTEOF        0x0000
#define DDE_EFFECTEOF          0x0001

#define DDE_SEARCHFRWD         0x0000
#define DDE_SEARCHBKWD         0x0001

#define DDE_SRCH               4

typedef struct tagPSSERVCOND
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  WORD      uPSStart;
  WORD      uPSLength;
  unsigned  uSearchDir;
  unsigned  uEOFflag;
  char      szTargetString[1];
} PSSERVCOND;

typedef PSSERVCOND FAR *LPPSSERVCOND;

typedef union tagDDE_PSCOND
{
  DDEPOKE     DDEpoke;
  PSSERVCOND  DDEPsCond;
} DDE_PSCOND;

typedef DDE_PSCOND FAR *LPDDE_PSCOND;

//***************************************************************
//
//  Set Advise Condition
//
//***************************************************************

typedef struct tagADVCOND
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  WORD      uPSStart;
  WORD      uPSLength;
  BOOL      bCaseSensitive;
  char      SearchString[1];
} ADVCOND;

typedef ADVCOND FAR *LPADVCOND;

typedef union tagDDE_ADVISECOND
{
  DDEPOKE     DDEpoke;
  ADVCOND     DDEAdviseCond;
} DDE_ADVISECOND;

typedef DDE_ADVISECOND FAR *LPDDE_ADVISECOND;

//***************************************************************
//
//  Set Structured Field Service Conditiion
//
//***************************************************************

typedef struct tagSFCOND
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  WORD      uBufferLength;
  WORD      uQRLength;
  char      szQueryReply[1];
} SFCOND;

typedef SFCOND FAR *LPSFCOND;

typedef union tagDDE_SFCOND
{
  DDEPOKE     DDEpoke;
  SFCOND      DDEsfcond;
} DDE_SFCOND;

typedef DDE_SFCOND FAR *LPDDE_SFCOND;

//***************************************************************
//
//  Write Structured Field
//
//***************************************************************

typedef struct tagWRITESF
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  WORD      uSFLength;
  char      Work[8];
  char      szSFData[1];
} WRITESF;

typedef WRITESF FAR *LPWRITESF;

typedef union tagDDE_WRITESF
{
  DDEPOKE     DDEpoke;
  WRITESF     DDEwritesf;
} DDE_WRITESF;

typedef DDE_WRITESF FAR *LPDDE_WRITESF;

//***************************************************************
//
//  Read Structured Field
//
//***************************************************************

typedef struct tagREADSF
{
  uchar     ddedata[(sizeof(DDEDATA)-1)];
  WORD      uSFLength;
  char      szSFData[1];
} READSF;

typedef READSF FAR *LPREADSF;

typedef union tagDDE_READSF
{
  DDEDATA     DDEdata;
  READSF      DDEreadsf;
} DDE_READSF;

typedef DDE_READSF FAR *LPDDE_READSF;

//***************************************************************
//
//  Find Field
//
//***************************************************************

typedef struct tagPSFIELDS
{
  BYTE      ubAttribute;
  unsigned  uFieldStart;
  unsigned  uFieldLength;
} PSFIELDS;

typedef PSFIELDS FAR *LPPSFIELDS;

typedef struct tagFINDFIELD
{
  uchar     data[(sizeof(DDEDATA)-1)];
  PSFIELDS  field;
} FINDFIELD;

typedef FINDFIELD FAR *LPFINDFIELD;

typedef union tagDDE_FIELD
{
  DDEDATA     DDEdata;
  FINDFIELD   DDEFindField;
} DDE_FIELD;

typedef DDE_FIELD FAR *LPDDE_FIELD;

//***************************************************************
//
//  Search for String
//
//***************************************************************

typedef struct tagPSSEARCH
{
  unsigned  uPSStart;
} PSSEARCH;

typedef PSSEARCH FAR *LPPSSEARCH;

typedef struct tagSRCHSTRING
{
  uchar     data[(sizeof(DDEDATA)-1)];
  PSSEARCH  search;
} SRCHSTRING;

typedef SRCHSTRING FAR *LPSRCHSTRING;

typedef union tagDDE_SEARCH
{
  DDEDATA     DDEdata;
  SRCHSTRING  DDESearch;
} DDE_SEARCH;

typedef DDE_SEARCH FAR *LPDDE_SEARCH;


//***************************************************************
//
//  Close Intercept
//
//***************************************************************

typedef struct tagCLOSECOUNT
{
  unsigned  uCloseReqCount;
} CLOSECOUNT;

typedef CLOSECOUNT FAR *LPCLOSECOUNT;

typedef struct tagCLOSEINT
{
  uchar       data[(sizeof(DDEDATA)-1)];
  CLOSECOUNT  closedata;
} CLOSEINT;

typedef CLOSEINT FAR *LPCLOSEINT;

typedef union tagDDE_CLOSE
{
  DDEDATA     DDEdata;
  CLOSEINT    DDEclose;
} DDE_CLOSE;

typedef DDE_CLOSE FAR *LPDDE_CLOSE;

//***************************************************************
//
//  Keystrokes Intercept
//
//***************************************************************

typedef struct tagKEYINT
{
  uchar     data[(sizeof(DDEDATA)-1)];
  unsigned  uKeyType;
  uchar     KeyData[1];
} KEYINT;

typedef union tagDDE_KEYINT
{
  DDEDATA     DDEdata;
  KEYINT      DDEkey;
} DDE_KEYINT;

typedef DDE_KEYINT FAR *LPDDE_KEYINT;

#define    DDE_CHARACTER    0
#define    DDE_TOKEN        1

//***************************************************************
//
//  Get OIA
//
//***************************************************************

typedef struct tagGETOIA
{
  uchar     data[(sizeof(DDEDATA)-1)];
  uchar     OiaData[80];
} GETOIA;

typedef union tagDDE_OIA
{
  DDEDATA     DDEdata;
  GETOIA      DDEoia;
} DDE_OIA;

typedef DDE_OIA FAR *LPDDE_OIA;

//***************************************************************
//
//  Get PS
//
//***************************************************************

typedef struct tagPS_CF_TEXT
{
  uchar     data[(sizeof(DDEDATA)-1)];
  uchar     PSSIZE[4];
  uchar     Tab1[1];
  uchar     PSROWS[4];
  uchar     Tab2[1];
  uchar     PSCOLS[4];
  uchar     Tab3[1];
  uchar     PS[1];
} PS_CF_TEXT;

typedef PS_CF_TEXT FAR *LPPS_CF_TEXT;

typedef union tagDDE_PS_CF_TEXT
{
  DDEDATA     DDEdata;
  PS_CF_TEXT  DDEps;
} DDE_PS_CF_TEXT;

typedef DDE_PS_CF_TEXT FAR *LPDDE_PS_CF_TEXT;

typedef struct tagPS_FIELD
{
  uchar     FieldStart[4];
  uchar     TabF1[1];
  uchar     FieldLength[4];
  uchar     TabF2[1];
  uchar     Attribute;
  uchar     TabF3[1];
} PS_FIELD;

typedef PS_FIELD FAR *LPPS_FIELD;

typedef struct tagFL_CF_TEXT
{
  uchar     Tab4[1];
  uchar     PSFldCount[4];
  uchar     Tab5[1];
  PS_FIELD  Field[1];
} FL_CF_TEXT;

typedef FL_CF_TEXT FAR *LPFL_CF_TEXT;

typedef struct tagPS_CF_DSPTEXT
{
  uchar     data[(sizeof(DDEDATA)-1)];
  unsigned  uPSSize;
  unsigned  uPSRows;
  unsigned  uPSCols;
  unsigned  uPSOffset;
  unsigned  uFieldCount;
  unsigned  uFieldOffset;
  uchar     PSData[1];
} PS_CF_DSPTEXT;

typedef PS_CF_DSPTEXT FAR *LPPS_CF_DSPTEXT;

typedef union tagDDE_PS_CF_DSPTEXT
{
  DDEDATA        DDEdata;
  PS_CF_DSPTEXT  DDEps;
} DDE_PS_CF_DSPTEXT;

typedef DDE_PS_CF_DSPTEXT FAR *LPDDE_PS_CF_DSPTEXT;


//***************************************************************
//
//  Get Partial PS
//
//***************************************************************

typedef struct tagEPS_CF_TEXT
{
  uchar     data[(sizeof(DDEDATA)-1)];
  uchar     PSPOSITION[4];
  uchar     Tab1[1];
  uchar     PSLENGTH[4];
  uchar     Tab2[1];
  uchar     PSROWS[4];
  uchar     Tab3[1];
  uchar     PSCOLS[4];
  uchar     Tab4[1];
  uchar     PS[1];
} EPS_CF_TEXT;

typedef EPS_CF_TEXT FAR *LPEPS_CF_TEXT;

typedef union tagDDE_EPS_CF_TEXT
{
  DDEDATA     DDEdata;
  EPS_CF_TEXT DDEeps;
} DDE_EPS_CF_TEXT;

typedef DDE_EPS_CF_TEXT FAR *LPDDE_EPS_CF_TEXT;

typedef struct tagEPS_CF_DSPTEXT
{
  uchar     data[(sizeof(DDEDATA)-1)];
  unsigned  uPSPosition;
  unsigned  uPSLength;
  unsigned  uPSRows;
  unsigned  uPSCols;
  unsigned  uPSOffset;
  unsigned  uFieldCount;
  unsigned  uFieldOffset;
  uchar     PSData[1];
} EPS_CF_DSPTEXT;

typedef EPS_CF_DSPTEXT FAR *LPEPS_CF_DSPTEXT;

typedef union tagDDE_EPS_CF_DSPTEXT
{
  DDEDATA        DDEdata;
  EPS_CF_DSPTEXT DDEeps;
} DDE_EPS_CF_DSPTEXT;

typedef DDE_EPS_CF_DSPTEXT FAR *LPDDE_EPS_CF_DSPTEXT;

//***************************************************************
//
//  DDE Menu
//
//***************************************************************

#define    MAX_DDE_NUMBER_ITEMS   1
#define    MAX_DDE_SUBMENU_ITEMS  32

typedef struct tagDDEMENUINFO
{
  uchar  zMenuBarToken[17];
  int    iMenuBarCount;
  int    iSubMenuCount;
  struct
  {
    WORD   uSubMenuID;
    uchar  zSubMenuItem[17];
    uchar  zSubMenuText[33];
  } DDESubMenu[MAX_DDE_SUBMENU_ITEMS];
} DDEMENUINFO;

typedef DDEMENUINFO      *PDDEMENUINFO;
typedef DDEMENUINFO FAR *LPDDEMENUINFO;

//***************************************************************
//
//  DDE Menu Create Menu Item
//
//***************************************************************

typedef struct tagCREATEMENU
{
  uchar     data[(sizeof(DDEDATA)-1)];
  HMENU     hMenuItem;
} CREATEMENU;

typedef union tagDDE_CREATEMENU
{
  DDEDATA     DDEdata;
  CREATEMENU  DDEmenu;
} DDE_CREATEMENU;

typedef DDE_CREATEMENU FAR *LPDDE_CREATEMENU;

//***************************************************************
//
//  DDE Menu Change Menu Item
//
//***************************************************************

typedef struct tagCHANGEMENU
{
  uchar     ddepoke[(sizeof(DDEPOKE)-1)];
  HMENU     hMenu;
  WORD      wPosition;
  WORD      wIDNew;
  WORD      wOperation;
  WORD      wFlags;
  uchar     szItemName[1];
} CHANGEMENU;

typedef CHANGEMENU FAR *LPCHANGEMENU;

typedef union tagDDE_CHANGEMENU
{
  DDEPOKE     DDEpoke;
  CHANGEMENU  DDEmenu;
} DDE_CHANGEMENU;

typedef DDE_CHANGEMENU FAR *LPDDE_CHANGEMENU;

//***************************************************************
//
//  DDE Menu Select Menu Item
//
//***************************************************************

typedef struct tagSELECTMENU
{
  uchar     data[(sizeof(DDEDATA)-1)];
  WORD      uIDSelected;
} SELECTMENU;

typedef union tagDDE_SELECTMENU
{
  DDEDATA     DDEdata;
  SELECTMENU  DDEmenu;
} DDE_SELECTMENU;

typedef DDE_SELECTMENU FAR *LPDDE_SELECTMENU;
